==> open-xchange-documents-backend_7.8.4.orig.tar.bz2: open-xchange-documents-backend-7.8.4/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/odf/properties/TableColumnProperties.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * @author sven.jacobi@open-xchange.com
 */

package com.openexchange.office.filter.odf.properties;

import java.util.Iterator;
import java.util.Map;
import java.util.Map.Entry;
import org.json.JSONObject;
import com.openexchange.office.filter.odf.AttributesImpl;
import com.openexchange.office.filter.odf.Namespaces;
import com.openexchange.office.filter.odf.OpAttrs;
import com.openexchange.office.filter.odf.styles.StyleManager;

final public class TableColumnProperties extends StylePropertiesBase {

	public TableColumnProperties(AttributesImpl attributesImpl) {
		super(attributesImpl);
	}

	@Override
	public String getQName() {
		return "style:table-column-properties";
	}

	@Override
	public String getLocalName() {
		return "table-column-properties";
	}

	@Override
	public String getNamespace() {
		return Namespaces.STYLE;
	}

	@Override
	public void applyAttrs(StyleManager styleManager, JSONObject attrs) {
        final JSONObject columnAttrs = attrs!=null ? attrs.optJSONObject("column") : null;
        if(columnAttrs!=null) {
        	final Iterator<Entry<String, Object>> columnAttrsIter = columnAttrs.entrySet().iterator();
        	while(columnAttrsIter.hasNext()) {
        		final Entry<String, Object> columnAttrsEntry = columnAttrsIter.next();
				final Object columnAttrsValue = columnAttrsEntry.getValue();
				if(columnAttrsValue!=null) {
	        		switch(columnAttrsEntry.getKey()) {
	        			case "width": {
	        				if(columnAttrsValue==JSONObject.NULL) {
	        					attributes.remove("style:column-width");
	        				}
	        				else {
	        					attributes.setLength100thmm(Namespaces.STYLE, "column-width", "style:column-width", ((Number)columnAttrsValue).intValue());
	        				}
	        				break;
	        			}
	        		}
				}
        	}
        }
	}

	@Override
	public void createAttrs(StyleManager styleManager, boolean contentAutoStyle, OpAttrs attrs) {
		final Map<String, Object> columnAttrs = attrs.getMap("column", true);
		final Integer width = attributes.getLength100thmm("style:column-width", false);
		if(width!=null) {
            columnAttrs.put("width", width);
		}
		final String optimalColumnWidth = attributes.getValue("style:use-optimal-column-width");
		if(optimalColumnWidth!=null) {
			columnAttrs.put("customWidth", !Boolean.parseBoolean(optimalColumnWidth));
		}
		if(columnAttrs.isEmpty()) {
			attrs.remove("column");
		}
	}

	@Override
	public TableColumnProperties clone() {
		return (TableColumnProperties)_clone();
	}
}

==> open-xchange-documents-backend_7.10.0.orig.tar.bz2: open-xchange-documents-backend-7.10.0/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/odf/properties/TableColumnProperties.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * @author sven.jacobi@open-xchange.com
 */

package com.openexchange.office.filter.odf.properties;

import java.util.Iterator;
import java.util.Map;
import java.util.Map.Entry;
import org.json.JSONObject;
import com.openexchange.office.filter.api.OCKey;
import com.openexchange.office.filter.odf.AttributesImpl;
import com.openexchange.office.filter.odf.Namespaces;
import com.openexchange.office.filter.odf.OpAttrs;
import com.openexchange.office.filter.odf.styles.StyleManager;

final public class TableColumnProperties extends StylePropertiesBase {

	public TableColumnProperties(AttributesImpl attributesImpl) {
		super(attributesImpl);
	}

	@Override
	public String getQName() {
		return "style:table-column-properties";
	}

	@Override
	public String getLocalName() {
		return "table-column-properties";
	}

	@Override
	public String getNamespace() {
		return Namespaces.STYLE;
	}

	@Override
	public void applyAttrs(StyleManager styleManager, JSONObject attrs) {
        final JSONObject columnAttrs = attrs!=null ? attrs.optJSONObject(OCKey.COLUMN.value()) : null;
        if(columnAttrs!=null) {
        	final Iterator<Entry<String, Object>> columnAttrsIter = columnAttrs.entrySet().iterator();
        	while(columnAttrsIter.hasNext()) {
        		final Entry<String, Object> columnAttrsEntry = columnAttrsIter.next();
				final Object columnAttrsValue = columnAttrsEntry.getValue();
				if(columnAttrsValue!=null) {
	        		switch(OCKey.fromValue(columnAttrsEntry.getKey())) {
	        			case WIDTH : {
	        				if(columnAttrsValue==JSONObject.NULL) {
	        					attributes.remove("style:column-width");
	        				}
	        				else {
	        					attributes.setLength100thmm(Namespaces.STYLE, "column-width", "style:column-width", ((Number)columnAttrsValue).intValue());
	        				}
	        				break;
	        			}
	        		}
				}
        	}
        }
	}

	@Override
	public void createAttrs(StyleManager styleManager, boolean contentAutoStyle, OpAttrs attrs) {
		final Map<String, Object> columnAttrs = attrs.getMap(OCKey.COLUMN.value(), true);
		final Integer width = attributes.getLength100thmm("style:column-width", false);
		if(width!=null) {
            columnAttrs.put(OCKey.WIDTH.value(), width);
		}
		final String optimalColumnWidth = attributes.getValue("style:use-optimal-column-width");
		if(optimalColumnWidth!=null) {
			columnAttrs.put(OCKey.CUSTOM_WIDTH.value(), !Boolean.parseBoolean(optimalColumnWidth));
		}
		if(columnAttrs.isEmpty()) {
			attrs.remove(OCKey.COLUMN.value());
		}
	}

	@Override
	public TableColumnProperties clone() {
		return (TableColumnProperties)_clone();
	}
}
